package com.sky.aspect;


import com.sky.annotation.AutoFill;
import com.sky.context.BaseContext;
import com.sky.enumeration.OperationType;
import lombok.extern.slf4j.Slf4j;
import org.aspectj.lang.JoinPoint;
import org.aspectj.lang.Signature;
import org.aspectj.lang.annotation.Aspect;
import org.aspectj.lang.annotation.Before;
import org.aspectj.lang.annotation.Pointcut;
import org.aspectj.lang.reflect.MethodSignature;
import org.springframework.stereotype.Component;

import java.time.LocalDateTime;

/*
* 自定义切面类,实现公共字段数据填充
* */
@Aspect
@Component
@Slf4j
public class AutoFillAspect {
    /*
    * 切入点
    * */
    @Pointcut("execution(* com.sky.mapper.*.*(..)) && @annotation(com.sky.annotation.AutoFill)")
    public void autoFillPointCut(){}
        /*前置通知*/
    @Before("autoFillPointCut()")
    public void autoFill(JoinPoint joinPoint){
        log.info("开始进行公共字段填充···");
//        获取到当前被拦截的方法上的数据库操作类型
        MethodSignature signature =(MethodSignature) joinPoint.getSignature();//方法的签名对象
        AutoFill autoFill = signature.getMethod().getAnnotation(AutoFill.class);//获得方法上的注解对象
        OperationType operationType = autoFill.value();//获得数据库操作类型

//        获取到被拦截的方法的实体对象
        Object[] args = joinPoint.getArgs();
        if(args == null || args.length == 0){
            return;
        }
        Object entity = args[0];//获得第一个参数，约定第一个参数为实体对象

//        准备赋值的数据时间和当前id
        LocalDateTime now = LocalDateTime.now();
        Long currentId = BaseContext.getCurrentId();

//        根据不同的操作类型，为对应的属性通过反射来赋值
        if(operationType == OperationType.INSERT){
            try {
                entity.getClass().getDeclaredMethod("setCreateTime",LocalDateTime.class).invoke(entity,now);
                entity.getClass().getDeclaredMethod("setUpdateTime",LocalDateTime.class).invoke(entity,now);
                entity.getClass().getDeclaredMethod("setCreateUser",Long.class).invoke(entity,currentId);
                entity.getClass().getDeclaredMethod("setUpdateUser",Long.class).invoke(entity,currentId);
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
        else if(operationType == OperationType.UPDATE){
            try {
                entity.getClass().getDeclaredMethod("setUpdateTime",LocalDateTime.class).invoke(entity,now);
                entity.getClass().getDeclaredMethod("setUpdateUser",Long.class).invoke(entity,currentId);
            } catch (Exception e) {
                e.printStackTrace();
            }

        }

    }


}
